Booklets

Moda Stoq

Drawee Client
Installment 1 of 1 | Due date 03/03/12
Payment # 00666 | Value $10.50

Moda Stoq 24.198.774/7322-35

Drawee Client | Due date 03/03/12
Drawee's document | Drawee's phone number | Installment 1 of 1
Emission date 01/01/12 | Sale # | Payment # 00666 | Installments total | (=) Document value $10.50
Instructions Instruction line 1 Instruction line 2 Instruction line 3 Instruction line 4 Instruction line 5 Demonstrative | (+) Penalty
(+) Interest
(-) Discount
(=) Total value $10.50

# Promissory Note

## Payment local

Moda Stoq - 24.198.774/7322-35
Avendia São Carlos 2333, Centro
São Carlos / SP

## Issuer

Client
Mainstreet 138, Cidade Araci
Los Angeles / Californa

Number: | 00666
Emission date: | 01 de January de 2012
Due date: | 03 de March de 2012
Value: | $10.50